@@ -1,7 +1,6 @@
 `summary.homals` <-
 function(object, ...)
 {
-  cat("\nHomals results for ",object$datname,":\n", sep="")
   cat("\nNumber of dimensions:",object$ndim)
   cat("\nNumber of iterations:",object$niter)
   cat("\n")
@@ -14,10 +13,10 @@ function(object, ...)
     print(round(object$cat.loadings[[i]], 4))
     cat("\nCategory centroids:\n")
     print(round(object$cat.centroids[[i]], 4))
-    cat("\nRank-restricted category quantifications:\n")
+    cat("\nCategory quantifications (scores):\n")
     print(round(object$catscores[[i]], 4)) 
     cat("\nLower rank quantifications (rank = ",object$rank.vec[i],"):\n",sep="")
-    print(round(object$catscores[[i]], 4)) 
+    print(round(object$low.rank[[i]], 4)) 
   }
   cat("\n")
 }
